==> zio-aws-applicationinsights_2.12-5.17.130.7-sources.jar: zio/aws/applicationinsights/model/ListComponentsResponse.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.PaginationToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListComponentsResponse(
    applicationComponentList: Option[
      Iterable[zio.aws.applicationinsights.model.ApplicationComponent]
    ] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse = {
    import ListComponentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
      .builder()
      .optionallyWith(
        applicationComponentList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.applicationComponentList)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly =
    zio.aws.applicationinsights.model.ListComponentsResponse
      .wrap(buildAwsValue())
}
object ListComponentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.applicationinsights.model.ListComponentsResponse =
      zio.aws.applicationinsights.model.ListComponentsResponse(
        applicationComponentList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def applicationComponentList: Option[
      List[zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly]
    ]
    def nextToken: Option[PaginationToken]
    def getApplicationComponentList: ZIO[Any, AwsError, List[
      zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "applicationComponentList",
      applicationComponentList
    )
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ) extends zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly {
    override val applicationComponentList: Option[
      List[zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly]
    ] = scala
      .Option(impl.applicationComponentList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.applicationinsights.model.ApplicationComponent.wrap(item)
        }.toList
      )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ): zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-applicationinsights_2.12-5.17.202.1-sources.jar: zio/aws/applicationinsights/model/ListComponentsResponse.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.PaginationToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListComponentsResponse(
    applicationComponentList: Optional[
      Iterable[zio.aws.applicationinsights.model.ApplicationComponent]
    ] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse = {
    import ListComponentsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
      .builder()
      .optionallyWith(
        applicationComponentList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.applicationComponentList)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly =
    zio.aws.applicationinsights.model.ListComponentsResponse
      .wrap(buildAwsValue())
}
object ListComponentsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.applicationinsights.model.ListComponentsResponse =
      zio.aws.applicationinsights.model.ListComponentsResponse(
        applicationComponentList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def applicationComponentList: Optional[
      List[zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly]
    ]
    def nextToken: Optional[PaginationToken]
    def getApplicationComponentList: ZIO[Any, AwsError, List[
      zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "applicationComponentList",
      applicationComponentList
    )
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ) extends zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly {
    override val applicationComponentList: Optional[
      List[zio.aws.applicationinsights.model.ApplicationComponent.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.applicationComponentList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.applicationinsights.model.ApplicationComponent.wrap(item)
        }.toList
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListComponentsResponse
  ): zio.aws.applicationinsights.model.ListComponentsResponse.ReadOnly =
    new Wrapper(impl)
}
